@@ -3,7 +3,7 @@ package Alien::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.035_01';
+our $VERSION = '0.037_01';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -233,12 +233,12 @@ the Perl core L<Text::ParseWords> module.
 
 sub cflags {
   my $class = shift;
-  return $class->runtime_prop ? $class->_flags('cflags') : $class->_pkgconfig_keyword('Cflags', 'static');
+  return $class->runtime_prop ? $class->_flags('cflags') : $class->_pkgconfig_keyword('Cflags');
 }
 
 sub cflags_static {
   my $class = shift;
-  return $class->runtime_prop ? $class->_flags('cflags_static') : $class->_pkgconfig_keyword('Cflags');
+  return $class->runtime_prop ? $class->_flags('cflags_static') : $class->_pkgconfig_keyword('Cflags', 'static');
 }
 
 =head2 libs
